@@ -1,4 +1,4 @@
-from typing_extensions import Annotated, Any, Dict, Optional, TypedDict
+from typing_extensions import Annotated, Any, Dict, Optional, TypedDict, List
 
 from patchwork.common.utils.step_typing import StepTypeConfig
 
@@ -13,7 +13,12 @@ class BrowserUseInputs(__BrowserUseInputsRequired, total=False):
     openai_api_key: Annotated[str, StepTypeConfig(or_op=["google_api_key", "anthropic_api_key"])]
     anthropic_api_key: Annotated[str, StepTypeConfig(or_op=["google_api_key", "openai_api_key"])]
     google_api_key: Annotated[str, StepTypeConfig(or_op=["openai_api_key", "anthropic_api_key"])]
-    generate_gif: Optional[bool]
+    gif_path: Optional[str]
+    headless: Optional[bool]
+    initial_actions: Optional[List[Dict[str, Dict[str, Any]]]]
+    downloads_path: Optional[str]
+    use_vision: Optional[bool]
+    timeout: Optional[int]  # optional timeout in seconds, defaults to 600 if not provided
 
 
 class BrowserUseOutputs(TypedDict):
